@@ -8,6 +8,7 @@ my $debug = 0;
 $debug = 1 if $ARGV[0] and $ARGV[0] eq '-d';
 
 $ENV{LESSOPEN} = "|./lesspipe.sh %s";
+$ENV{PATH} .= ":."; # make sure we do find sxw2txt
 open F, "TESTCMDS" or die "Could not read TESTCMDS:$!\n";
 my $retcode = 0;
 while (<F>) {
@@ -17,6 +18,7 @@ while (<F>) {
   my $ignore = $_ =~ s/#\s*ignore error*//;
   my $res = `$_ 2>&1`;
   my $ok = 0;
+  my $lines = 0;
   if ( $res and $res =~ /command not found: (\S+)/m ) {  # zsh style
     print "result:$res" if $debug;
     $res = "NOT found: $1";
@@ -43,17 +45,24 @@ while (<F>) {
     $ok = $res[0] =~ s/^test \(1\)\s+.*/test/ if $res[0] and ! $ok;
     # special case for perl storable
     $ok = $res[0] =~ s/^\$VAR1 = \\'test';$/test/ if $res[0] and ! $ok;
+    # special case for mp3
+    if ($res[1] and ! $ok) {
+        $ok = $res[1] =~ s/.*Title.*:\s+test\b.*/test/;
+        $res[0] = $res[1] if $ok;
+    }
     $res = $res[0] if $res[0];
+    $lines = $#res;
   }
   if ( $ok ) {
     $res =~ s/test/ok/ if $ok;
     $res =~ s/^\s+// if $ok;
+    $res .= " ($lines trailing lines)" if $lines;
   } else {
     $retcode++ if ! $ok and ! $ignore;
     $res = "NOT ok";
     $res .= " (ignored)" if $ignore;
   }
-  printf "%-55s %s\n", $_, $res;
+  printf "%-56s %s\n", $_, $res;
 }
 close F;
 exit $retcode;
